var Test = function() {
    var Test__2 = function() {
        function Test__3() {}
        return Test__3;
    }();
    return Test__2;
}();
